stravalib.util.limiter.LimitStructure
=====================================

.. currentmodule:: stravalib.util.limiter

.. autoclass:: LimitStructure


   .. automethod:: __init__


   .. rubric:: Methods

   .. autosummary::

      ~LimitStructure.__init__
      ~LimitStructure.clear
      ~LimitStructure.copy
      ~LimitStructure.fromkeys
      ~LimitStructure.get
      ~LimitStructure.items
      ~LimitStructure.keys
      ~LimitStructure.pop
      ~LimitStructure.popitem
      ~LimitStructure.setdefault
      ~LimitStructure.update
      ~LimitStructure.values





   .. rubric:: Attributes

   .. autosummary::

      ~LimitStructure.usage
      ~LimitStructure.limit
      ~LimitStructure.time
      ~LimitStructure.lastExceeded
